var indexSectionsWithContent =
{
  0: "acdfghiklmnoprstu",
  1: "l",
  2: "acdfglnprst",
  3: "l",
  4: "co",
  5: "l",
  6: "l",
  7: "l",
  8: "l",
  9: "adgikpt",
  10: "acdfghlmnprstu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

